@@ -1,3 +1,5 @@
+from typing import Optional
+
 from lxml import etree
 from pydantic import BaseModel
 
@@ -13,34 +15,42 @@ class CDA(BaseModel):
     id: int
     mensaje_id: int
     op_fecha_oper: str
+    op_fecha_abono: str
     op_hora_abono: str
+
     op_cve_rastreo: str
 
+    op_folio_orig_odp: int
+    op_folio_orig_paq: int
+
     op_clave_emisor: str
     op_nombre_emisor: str
 
-    op_nom_ord: str
-    op_tp_cta_ord: types.TipoCuentaOrdenPago
-    op_cuenta_ord: str
-    op_rfc_curp_ord: str
+    op_tipo_pag: types.TipoPagoOrdenPago
+
+    op_monto: str
 
     op_nombre_receptor: str
 
-    op_nom_ben: str
-    op_tp_cta_ben: types.TipoCuentaOrdenPago
-    op_cuenta_ben: str
-    op_rfc_curp_ben: str
+    op_concepto_pag: Optional[str] = None
+    op_concepto_pag_2: Optional[str] = None
 
-    op_tipo_pag: str
-    op_concepto_pag: str
+    op_nom_ord: Optional[str] = None
+    op_tp_cta_ord: Optional[types.TipoCuentaOrdenPago] = None
+    op_cuenta_ord: Optional[str] = None
+    op_rfc_curp_ord: Optional[str] = None
 
-    op_iva: str = None
-    op_monto: str = None
-    op_hora_00: str = None
-    op_fecha_abono: str = None
+    op_nom_ben: Optional[str] = None
+    op_tp_cta_ben: Optional[types.TipoCuentaOrdenPago] = None
+    op_cuenta_ben: Optional[str] = None
+    op_rfc_curp_ben: Optional[str] = None
 
-    op_folio_orig_odp: int = None
-    op_folio_orig_paq: int = None
+    op_iva: Optional[str] = None
+    op_hora_00: Optional[str] = None
+
+    op_nom_part_indirecto_ord: Optional[str] = None
+    op_cta_part_indirecto_ord: Optional[str] = None
+    op_rfc_curp_part_indirecto_ord: Optional[str] = None
 
     class Config:  # noqa: WPS306, WPS431
         use_enum_values = True
@@ -58,7 +68,10 @@ class CDA(BaseModel):
         for element, value in elements.items():  # noqa: WPS110
             if element in self.__fields__:
                 upper_camel_case_element = to_upper_camel_case(element)
-                subelement = etree.SubElement(mensaje, etree.QName(ENVIO_PRAXIS_NS, upper_camel_case_element))  # noqa: E501
+                subelement = etree.SubElement(
+                    mensaje,
+                    etree.QName(ENVIO_PRAXIS_NS, upper_camel_case_element),
+                )  # noqa: E501
                 subelement.text = str(value)
 
         return mensaje
