@@ -1,4 +1,5 @@
 import re
+from typing import Optional
 
 from lxml import etree
 from pydantic import BaseModel, validator
@@ -30,78 +31,78 @@ class Orden(BaseModel):
     # checksum
     op_firma_dig: str
     # origin info
-    op_nom_ord: str = None
-    op_tc_clave_ord: types.TipoCuentaOrdenPago = None
-    op_cuenta_ord: str = None
-    op_rfc_curp_ord: str = None
-    op_ins_clave_ord: digits(3, 5) = None
+    op_nom_ord: Optional[str] = None
+    op_tc_clave_ord: Optional[types.TipoCuentaOrdenPago] = None
+    op_cuenta_ord: Optional[str] = None
+    op_rfc_curp_ord: Optional[str] = None
+    op_ins_clave_ord: Optional[digits(3, 5)] = None  # type: ignore
     # destination info
-    op_nom_ben: str = None
-    op_tc_clave_ben: types.TipoCuentaOrdenPago = None
-    op_cuenta_ben: str = None
-    op_rfc_curp_ben: str = None
-    op_ins_clave_ben: digits(3, 5) = None
+    op_nom_ben: Optional[str] = None
+    op_tc_clave_ben: Optional[types.TipoCuentaOrdenPago] = None
+    op_cuenta_ben: Optional[str] = None
+    op_rfc_curp_ben: Optional[str] = None
+    op_ins_clave_ben: Optional[digits(3, 5)] = None  # type: ignore
     # participant info
-    op_cuenta_participante_ord: str = None
-    op_nom_participante_ord: str = None
-    op_rfc_participante_ord: str = None
+    op_cuenta_participante_ord: Optional[str] = None
+    op_nom_participante_ord: Optional[str] = None
+    op_rfc_participante_ord: Optional[str] = None
     # additional destination info
-    op_nom_ben_2: str = None
-    op_tc_clave_ben_2: types.TipoCuentaOrdenPago = None
-    op_cuenta_ben_2: str = None
-    op_rfc_curp_ben_2: str = None
+    op_nom_ben_2: Optional[str] = None
+    op_tc_clave_ben_2: Optional[types.TipoCuentaOrdenPago] = None
+    op_cuenta_ben_2: Optional[str] = None
+    op_rfc_curp_ben_2: Optional[str] = None
     # concept info
-    op_concepto_pago: str = None
-    op_concepto_pag_2: str = None
+    op_concepto_pago: Optional[str] = None
+    op_concepto_pag_2: Optional[str] = None
     # additional general info
-    op_iva: float = None
-    op_ref_numerica: str = None
-    op_ref_cobranza: str = None
-    op_clave_pago: str = None
+    op_iva: Optional[float] = None
+    op_ref_numerica: Optional[str] = None
+    op_ref_cobranza: Optional[str] = None
+    op_clave_pago: Optional[str] = None
     # refunds info
-    op_to_clave: int = None
-    op_cd_clave: types.TipoDevolucionOrdenPago = None
+    op_to_clave: Optional[int] = None
+    op_cd_clave: Optional[types.TipoDevolucionOrdenPago] = None
     # invoice info
-    op_info_factura: str = None
+    op_info_factura: Optional[str] = None
     # original info
-    op_folio_ori: int = None
-    paq_folio_ori: int = None
-    op_fecha_oper_ori: int = None
-    op_rastreo_ori: str = None
-    op_monto_intereses: float = None
-    op_monto_ori: float = None
+    op_folio_ori: Optional[int] = None
+    paq_folio_ori: Optional[int] = None
+    op_fecha_oper_ori: Optional[int] = None
+    op_rastreo_ori: Optional[str] = None
+    op_monto_intereses: Optional[float] = None
+    op_monto_ori: Optional[float] = None
     # beneficiary
-    op_indica_ben_rec: int = None
+    op_indica_ben_rec: Optional[int] = None
     # codi origin info
-    op_num_cel_ord: int = None
-    op_digito_ver_ord: int = None
+    op_num_cel_ord: Optional[int] = None
+    op_digito_ver_ord: Optional[int] = None
     # codi destination info
-    op_num_cel_ben: int = None
-    op_digito_ver_ben: int = None
+    op_num_cel_ben: Optional[int] = None
+    op_digito_ver_ben: Optional[int] = None
     # codi info
-    op_folio_codi: str = None
-    op_comision_trans: int = None
-    op_monto_comision: float = None
+    op_folio_codi: Optional[str] = None
+    op_comision_trans: Optional[int] = None
+    op_monto_comision: Optional[float] = None
     # codi merchant info
-    op_cert_comer_env: int = None
-    op_digito_ver_comer: int = None
+    op_cert_comer_env: Optional[int] = None
+    op_digito_ver_comer: Optional[int] = None
     # karpay system info
-    op_fecha_cap: int = None
-    op_folio_servidor: int = None
-    op_usu_autoriza: str = None
-    op_err_clave: types.CodigoError = None
-    op_razon_rechazo: str = None
-    op_hora_cap: int = None
-    op_hora_liq_bm: int = None
-    op_hora_liq_sist: int = None
-    op_cde: str = None
-    op_cuenta_dev: str = None
-    op_hora_lectura_host: int = None  # noqa: N815
-    op_hora_insercion: int = None
-    hr_deposito_acuse_banxico: int = None
-    paq_folio: int = None
-    ah_ar_clave: int = None
-    emp_clave: int = None
+    op_fecha_cap: Optional[int] = None
+    op_folio_servidor: Optional[int] = None
+    op_usu_autoriza: Optional[str] = None
+    op_err_clave: Optional[types.CodigoError] = None
+    op_razon_rechazo: Optional[str] = None
+    op_hora_cap: Optional[int] = None
+    op_hora_liq_bm: Optional[int] = None
+    op_hora_liq_sist: Optional[int] = None
+    op_cde: Optional[str] = None
+    op_cuenta_dev: Optional[str] = None
+    op_hora_lectura_host: Optional[int] = None  # noq]a: N815
+    op_hora_insercion: Optional[int] = None
+    hr_deposito_acuse_banxico: Optional[int] = None
+    paq_folio: Optional[int] = None
+    ah_ar_clave: Optional[int] = None
+    emp_clave: Optional[int] = None
 
     class Config:  # noqa: WPS306, WPS431
         use_enum_values = True
@@ -173,7 +174,10 @@ class Orden(BaseModel):
         for element in orden_element.getchildren():
             tag = to_snake_case(element.tag)
             if tag in cls.__fields__:
-                orden_data[tag] = element.text.strip()
+                if element.text:
+                    orden_data[tag] = element.text.strip()
+                else:
+                    orden_data[tag] = None
             if tag == 'op_ins_clave':
                 orden_data['op_ins_clave_ord'] = element.text
 
